document.addEventListener('DOMContentLoaded', () => {
    const connectBtn = document.getElementById('connectBtn');
    const statsSection = document.getElementById('stats');
    const loadingSection = document.querySelector('.loading');

    connectBtn.addEventListener('click', async () => {
        // Simulate loading state
        connectBtn.disabled = true;
        loadingSection.classList.remove('hidden');
        
        // Simulate API call delay
        await new Promise(resolve => setTimeout(resolve, 2000));
        
        // Show stats with animation
        loadingSection.classList.add('hidden');
        statsSection.classList.remove('hidden');
        
        // Animate numbers
        animateValue('engagementValue', 0, 12547, 2000);
        animateValue('tweetCount', 0, 483, 2000);
        
        // Sample top tweet data
        document.getElementById('topTweetContent').innerHTML = 
            "Just achieved a major milestone in my career! Thank you everyone for your support! 🚀 #Achievement #Grateful";
    });
    
    function animateValue(elementId, start, end, duration) {
        const element = document.getElementById(elementId);
        const range = end - start;
        const increment = end > start ? 1 : -1;
        const stepTime = Math.abs(Math.floor(duration / range));
        let current = start;
        
        const timer = setInterval(() => {
            current += increment;
            element.textContent = current.toLocaleString();
            if (current === end) {
                clearInterval(timer);
            }
        }, stepTime);
    }
    
    // Add scroll reveal animation
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.style.opacity = '1';
                entry.target.style.transform = 'translateY(0)';
            }
        });
    });

    document.querySelectorAll('.stat-card').forEach(card => {
        card.style.opacity = '0';
        card.style.transform = 'translateY(20px)';
        card.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
        observer.observe(card);
    });
});
